@@ -192,6 +192,8 @@ GameScene::GameScene(Game* p_game) : m_game(p_game)
     
     // create the info sidebar
     m_infoSidebar = new InfoSidebar(m_game, this);
+    connect(this, SIGNAL(resizeGraphics(qreal)), m_infoSidebar, SLOT(updateGraphics(qreal)));
+    
     //update the sceneRect
     QRectF oldSceneRect = sceneRect();
     QRectF sidebarRect = m_infoSidebar->rect();
@@ -205,6 +207,7 @@ GameScene::GameScene(Game* p_game) : m_game(p_game)
     
     // create the info overlay
     m_infoOverlay = new InfoOverlay(m_game, this);
+    connect(this, SIGNAL(resizeGraphics(qreal)), m_infoOverlay, SLOT(updateGraphics(qreal)));
     
     init();
     
