@@ -23,15 +23,16 @@
 from PyQt4.QtCore import SIGNAL, Qt, QVariant
 from PyQt4.QtGui import QWidget, QHBoxLayout, QVBoxLayout, \
     QPushButton, QSpacerItem, QSizePolicy, \
-    QTreeView, QItemDelegate, QSpinBox, QComboBox,  \
+    QTreeView, QStyledItemDelegate, QSpinBox, QComboBox,  \
     QFont, QAbstractItemView
 from PyQt4.QtCore import QAbstractItemModel, QModelIndex
 from scoringengine import Ruleset, PredefinedRuleset, Rule, Score
 from util import m18n, m18nc, i18nc, english, logException
 from statesaver import StateSaver
 from differ import RulesetDiffer
-#make predefined rulesets known:
-import predefined # pylint: disable-msg=W0611
+from common import Debug
+
+from modeltest import ModelTest
 
 class RuleTreeItem(object):
     """generic class for items in our rule tree"""
@@ -48,7 +49,7 @@ class RuleTreeItem(object):
         self.children.insert(row, child)
         return child
 
-    def remove(self): # pylint: disable-msg=R0201
+    def remove(self): # pylint: disable=R0201
         """remove this item from the model and the database.
         This is an abstract method."""
         raise Exception('cannot remove this RuleTreeItem. We should never get here.')
@@ -162,7 +163,12 @@ class RuleItem(RuleTreeItem):
 
     def tooltip(self):
         """tooltip for rule: just the name of the ruleset"""
-        return self.ruleset().name
+        ruleset = self.ruleset()
+        if self.rawContent.description:
+            return '<b>' + m18n(ruleset.name) + '</b><br><br>' + \
+                m18n(self.rawContent.description)
+        else:
+            return m18n(ruleset.name)
 
 class RuleModel(QAbstractItemModel):
     """a model for our rule table"""
@@ -190,24 +196,20 @@ class RuleModel(QAbstractItemModel):
 
     def columnCount(self, parent):
         """how many columns does this node have?"""
-        if parent.isValid():
-            return parent.internalPointer().columnCount()
-        else:
-            return self.rootItem.columnCount()
+        return self.itemForIndex(parent).columnCount()
 
-    def data(self, index, role): # pylint: disable-msg=R0201
+    def data(self, index, role): # pylint: disable=R0201
         """get data fom model"""
         result = QVariant()
         if index.isValid():
+            item = index.internalPointer()
             if role == Qt.DisplayRole:
-                item = index.internalPointer()
                 if index.column() == 1:
                     if isinstance(item, RuleItem) and item.rawContent.parType is bool:
-                        return QVariant()
+                        return QVariant('')
                 result = QVariant(item.content(index.column()))
             elif role == Qt.CheckStateRole:
                 if index.column() == 1:
-                    item = index.internalPointer()
                     if isinstance(item, RuleItem) and item.rawContent.parType is bool:
                         bData = item.content(index.column())
                         result =  QVariant(Qt.Checked if bData else Qt.Unchecked)
@@ -216,13 +218,12 @@ class RuleModel(QAbstractItemModel):
                 if index.column() == 1:
                     result = QVariant(int(Qt.AlignRight|Qt.AlignVCenter))
             elif role == Qt.FontRole and index.column() == 0:
-                ruleset = index.internalPointer().ruleset()
+                ruleset = item.ruleset()
                 if isinstance(ruleset, PredefinedRuleset):
                     font = QFont()
                     font.setItalic(True)
                     result = QVariant(font)
             elif role == Qt.ToolTipRole:
-                item = index.internalPointer()
                 tip = '<b></b>%s<b></b>' % m18n(item.tooltip()) if item else ''
                 result = QVariant(tip)
         return result
@@ -234,41 +235,52 @@ class RuleModel(QAbstractItemModel):
         else:
             return QVariant()
 
+    def itemForIndex(self, index):
+        """returns the item at index"""
+        if index.isValid():
+            item = index.internalPointer()
+            if item:
+                return item
+        return self.rootItem
+
     def index(self, row, column, parent):
         """generate an index for this item"""
-        if row < 0 or column < 0 or row >= self.rowCount(parent) or column >= self.columnCount(parent):
+        if self.rootItem is None:
             return QModelIndex()
-        if not parent.isValid():
-            parentItem = self.rootItem
-        else:
-            parentItem = parent.internalPointer()
-        childItem = parentItem.child(row)
-        if childItem:
-            return self.createIndex(row, column, childItem)
-        else:
+        if row < 0 or column < 0 or row >= self.rowCount(parent) or column >=  self.columnCount(parent):
             return QModelIndex()
+        parentItem = self.itemForIndex(parent)
+        assert parentItem
+        item = parentItem.child(row)
+        if item:
+            return self.createIndex(row, column, item)
+        return QModelIndex()
 
     def parent(self, index):
         """find the parent index"""
         if not index.isValid():
             return QModelIndex()
-        childItem = index.internalPointer()
-        parentItem = childItem.parent
-        if parentItem == self.rootItem or parentItem is None:
-            return QModelIndex()
-        return self.createIndex(parentItem.row(), 0, parentItem)
+        childItem = self.itemForIndex(index)
+        if childItem:
+            parentItem = childItem.parent
+            if parentItem:
+                if parentItem != self.rootItem:
+                    grandParentItem = parentItem.parent
+                    if grandParentItem:
+                        row = grandParentItem.children.index(parentItem)
+                        return self.createIndex(row, 0, parentItem)
+        return QModelIndex()
 
     def rowCount(self, parent):
         """how many items?"""
-        if not parent.isValid():
-            parentItem = self.rootItem
-        else:
-            parentItem = parent.internalPointer()
-        return parentItem.childCount()
+        if parent.isValid() and parent.column():
+            # all children have col=0 for parent
+            return 0
+        return self.itemForIndex(parent).childCount()
 
     def insertItems(self, position, items, parent=QModelIndex()):
         """inserts items into the model"""
-        parentItem = parent.internalPointer() if parent.isValid() else self.rootItem
+        parentItem = self.itemForIndex(parent)
         self.beginInsertRows(parent, position, position + len(items)- 1)
         for row, item in enumerate(items):
             parentItem.insert(position + row, item)
@@ -280,9 +292,8 @@ class RuleModel(QAbstractItemModel):
         if not ruleset:
             return
         ruleset.load()
-        root = self.rootItem
         parent = QModelIndex()
-        row = root.childCount()
+        row = self.rootItem.childCount()
         self.insertItems(row, list([RulesetItem(ruleset)]), parent)
         rulesetIndex = self.index(row, 0, parent)
         self.insertItems(0, list([RuleListItem(x) for x in ruleset.ruleLists]), rulesetIndex)
@@ -298,7 +309,7 @@ class EditableRuleModel(RuleModel):
     @staticmethod
     def __setRuleData(column, content, value):
         """change rule data in the model"""
-        # pylint:  disable-msg=R0912
+        # pylint:  disable=R0912
         # allow more than 12 branches
         dirty = False
         if column == 0:
@@ -340,7 +351,7 @@ class EditableRuleModel(RuleModel):
 
     def setData(self, index, value, role=Qt.EditRole):
         """change data in the model"""
-        # pylint:  disable-msg=R0912
+        # pylint:  disable=R0912
         # allow more than 12 branches
         if not index.isValid():
             return False
@@ -384,7 +395,7 @@ class EditableRuleModel(RuleModel):
         except BaseException:
             return False
 
-    def flags(self, index): # pylint: disable-msg=R0201
+    def flags(self, index): # pylint: disable=R0201
         """tell the view what it can do with this item"""
         if not index.isValid():
             return Qt.ItemIsEnabled
@@ -409,21 +420,18 @@ class EditableRuleModel(RuleModel):
 
     def removeRows(self, position, rows=1, parent=QModelIndex()):
         """reimplement QAbstractItemModel.removeRows"""
-        if parent.isValid():
-            parentItem = parent.internalPointer()
-        else:
-            parentItem = self.rootItem
         self.beginRemoveRows(parent, position, position + rows - 1)
+        parentItem = self.itemForIndex(parent)
         for row in parentItem.children[position:position + rows]:
             row.remove()
         parentItem.children = parentItem.children[:position] + parentItem.children[position + rows:]
         self.endRemoveRows()
         return True
 
-class RuleDelegate(QItemDelegate):
+class RuleDelegate(QStyledItemDelegate):
     """delegate for rule editing"""
     def __init__(self, parent=None):
-        QItemDelegate.__init__(self, parent)
+        QStyledItemDelegate.__init__(self, parent)
 
     def createEditor(self, parent, option, index):
         """create field editors"""
@@ -440,26 +448,26 @@ class RuleDelegate(QItemDelegate):
             comboBox = QComboBox(parent)
             comboBox.addItems(list([m18n(x) for x in Score.unitNames]))
             return comboBox
-        return QItemDelegate.createEditor(self, parent, option, index)
+        return QStyledItemDelegate.createEditor(self, parent, option, index)
 
     def setEditorData(self, editor, index):
         """initialize editors"""
         text = index.model().data(index, Qt.DisplayRole).toString()
         column = index.column()
+        item = index.internalPointer()
         if column in (0, 3):
             editor.setText(text)
         elif column == 1:
-            item = index.internalPointer()
             if item.rawContent.parType is int:
                 editor.setValue(text.toInt()[0])
             else:
                 editor.setText(text)
         elif column == 2:
-            rule = index.internalPointer().rawContent
+            rule = item.rawContent
             assert isinstance(rule, Rule)
             editor.setCurrentIndex(rule.score.unit)
         else:
-            QItemDelegate.setEditorData(self, editor, index)
+            QStyledItemDelegate.setEditorData(self, editor, index)
 
     def setModelData(self, editor, model, index):
         """move changes into model"""
@@ -473,7 +481,7 @@ class RuleDelegate(QItemDelegate):
                 item.ruleset().dirty = True
                 model.emit(SIGNAL("dataChanged(QModelIndex,QModelIndex)"), index, index)
             return
-        QItemDelegate.setModelData(self, editor, model, index)
+        QStyledItemDelegate.setModelData(self, editor, model, index)
 
 class RuleTreeView(QTreeView):
     """Tree view for our rulesets"""
@@ -499,7 +507,7 @@ class RuleTreeView(QTreeView):
             differ.rulesetChanged()
 
     @apply
-    def rulesets(): # pylint: disable-msg=E0202
+    def rulesets(): # pylint: disable=E0202
         """a list of rulesets made available by this model"""
         def fget(self):
             return self.ruleModel.rulesets
@@ -510,6 +518,8 @@ class RuleTreeView(QTreeView):
                 else:
                     self.ruleModel = RuleModel(rulesets, self.name)
                 self.setModel(self.ruleModel)
+                if Debug.modelTest:
+                    self.ruleModelTest = ModelTest(self.ruleModel, self)
         return property(**locals())
 
     def selectionChanged(self, selected, dummyDeselected):
@@ -539,6 +549,7 @@ class RuleTreeView(QTreeView):
         self.expandAll() # because resizing only works for expanded fields
         for col in range(4):
             self.resizeColumnToContents(col)
+        self.setColumnWidth(0, self.geometry().width()/2)
         self.collapseAll()
         # now restore saved column widths
         StateSaver(self.header())
@@ -549,12 +560,6 @@ class RuleTreeView(QTreeView):
         if len(rows) == 1:
             return rows[0]
 
-    def selectedItem(self):
-        """returns the currently selected item"""
-        row = self.selectedRow()
-        if row:
-            return row.internalPointer()
-
     def copyRow(self):
         """copy a ruleset or a rule"""
         row = self.selectedRow()
@@ -577,7 +582,7 @@ class RuleTreeView(QTreeView):
         row = self.selectedRow()
         if row:
             assert not isinstance(row.internalPointer().ruleset(), PredefinedRuleset)
-            self.model().removeRow(row.row(), row.parent())
+            self.model().removeRows(row.row(), parent=row.parent())
 
     def compareRow(self):
         """shows the difference between two rulesets"""
