@@ -1,13 +1,8 @@
 /*
-
-    $Id: kmahjongg.h 465369 2005-09-29 14:33:08Z mueller $
-
     kmahjongg, the classic mahjongg game for KDE project
 
-    Requires the Qt widget libraries, available at no cost at
-    http://www.troll.no
-
     Copyright (C) 1997 Mathias Mueller   <in5y158@public.uni-hamburg.de>
+    Copyright (C) 2006-2007 Mauricio Piacentini   <mauricio@tabuleiro.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,48 +23,75 @@
 #ifndef _KMAHJONGG_H
 #define _KMAHJONGG_H
 
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 
 #include "KmTypes.h"
-#include "Tileset.h"
-#include "Background.h"
+#include "kmahjonggtileset.h"
+#include "kmahjonggbackground.h"
 #include "BoardLayout.h"
-#include "Preview.h"
-#include "HighScore.h"
 #include "boardwidget.h"
 
-class GameTimer;
-class Editor;
-
+class QAction;
 class KToggleAction;
 class QLabel;
+class KGameClock;
 
 /**
-    ...
-    @author Mathias
+   @short  Class Description
+
+   @author Mathias
 */
-class KMahjongg : public KMainWindow
+class KMahjongg : public KXmlGuiWindow
 {
     Q_OBJECT
 
     public:
-        KMahjongg( QWidget* parent = 0, const char *name = 0);
+    /**
+     * Constructor @param parent */
+        explicit KMahjongg( QWidget* parent = 0 );
+    /**
+     * Default Destructor */
         ~KMahjongg();
 
     public slots:
-        void startNewGame( int num = -1 );
-        void showStatusText ( const QString& , long);
-        void showTileNumber( int iMaximum, int iCurrent, int iLeft );
-        void demoModeChanged( bool bActive );
-        void gameOver( unsigned short removed, unsigned short cheats);
-	void loadBoardLayout(const QString&);
+    /**
+     * Slot Description @param num */
+    void startNewGame( int num = -1 );
+    /**
+     * Slot Description
+     * @param msg
+     * @param board
+     */
+    void showStatusText ( const QString &msg, long board);
+    /**
+     * Slot Description
+     * @param iMaximum
+     * @param iCurrent
+     * @param iLeft
+     */
+    void showTileNumber( int iMaximum, int iCurrent, int iLeft );
+    /**
+     * Slot Description @param bActive */
+    void demoModeChanged( bool bActive );
+    /**
+     * Slot Description
+     * @param removed
+     * @param cheats
+     */
+    void gameOver( unsigned short removed, unsigned short cheats);
+    /**
+     * Load BoardLayout from file @param file*/
+//	void loadBoardLayout(const QString &file);
+    /**
+     * Slot Description */
 	void setDisplayedWidth();
+    /**
+     * Slot Description */
 	void newGame();
+    /**
+     * Slot Description */
 	void timerReset();
 
-	void tileSizeChanged();
-
-
 private slots:
   void showSettings();
 
@@ -81,18 +103,17 @@ private slots:
   void redo();
   void pause();
   void demoMode();
-  void showMatchingTiles();
+  void displayTime(const QString& timestring);
   void showHighscores();
-  void slotBoardEditor();
-  void openTheme();
-  void saveTheme();
-  void openLayout();
-  void openBackground();
-  void openTileset();
+  //void slotBoardEditor();
 
 protected:
-  void setupKAction();
-  void setupStatusBar();
+    /**
+     * Method Description */
+    void setupKAction();
+    /**
+     * Method Description */
+    void setupStatusBar();
 
 private:
   // number of seconds since the start of the game
@@ -102,16 +123,14 @@ private:
   QLabel *gameNumLabel;
   QLabel *tilesLeftLabel;
   QLabel *statusLabel;
+  QLabel *gameTimerLabel;
 
-  GameTimer    *gameTimer;
-  HighScore    *theHighScores;
-  Preview      *previewLoad;
-  Editor*      boardEditor;
+  KGameClock    *gameTimer;
 
   bool         bDemoModeActive;
 
-  KToggleAction *showMatchingTilesAction, *pauseAction, *demoAction;
-  KAction *undoAction, *redoAction;
+  KToggleAction *pauseAction, *demoAction;
+  QAction *undoAction, *redoAction;
 
 };
 
