@@ -54,6 +54,10 @@ int main(int argc, char ** argv)
                     ki18n("icon design"),
                     "eugene.trounev@gmail.com");
 
+    about.addCredit(ki18n("Brian Croom"),
+                    ki18n("Port to use the QGraphicsView framework"),
+                    "brian.s.croom@gmail.com");
+
     KCmdLineArgs::init(argc, argv, &about);
 
     KCmdLineOptions options;
@@ -64,7 +68,7 @@ int main(int argc, char ** argv)
     KCmdLineArgs::addCmdLineOptions(options);
 
     KApplication application;
-    KGlobal::locale()->insertCatalog("libkdegames");
+    KGlobal::locale()->insertCatalog( QLatin1String( "libkdegames" ));
 
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
     if (args->isSet("Easy")) {
