@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 1995 Paul Olav Tvete <paul@troll.no>
  * Copyright (C) 2000-2008 Stephan Kulow <coolo@kde.org>
- * Copyright (C) 2009 Parker Coates <parker.coates@kde.org>
+ * Copyright (C) 2009-2010 Parker Coates <parker.coates@kde.org>
  *
  * License of original code:
  * -------------------------------------------------------------------------
@@ -50,11 +50,23 @@
 
 
 PatienceView::PatienceView( QWidget * parent )
-  : QGraphicsView( parent )
+  : QGraphicsView( parent ),
+    KGameRendererClient( Renderer::self(), "background" )
 {
     setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
     setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
     setFrameStyle( QFrame::NoFrame );
+
+    // This makes the background of the widget transparent so that Oxygen's
+    // (or any other style's) window gradient is visible in unpainted areas of
+    // the scene.
+    QPalette p = palette();
+    QColor c = p.color( QPalette::Base );
+    c.setAlpha( 0 );
+    p.setColor( QPalette::Base, c );
+    setPalette( p );
+    setBackgroundRole( QPalette::Base );
+
     setAlignment( Qt::AlignLeft | Qt::AlignTop );
     setCacheMode( QGraphicsView::CacheBackground );
 }
@@ -75,15 +87,33 @@ void PatienceView::setScene( QGraphicsScene * scene )
 void PatienceView::resizeEvent( QResizeEvent * e )
 {
     QGraphicsView::resizeEvent( e );
+    setRenderSize( e->size() );
+    resetCachedContent();
     updateSceneSize();
 }
 
 
-void PatienceView::drawBackground( QPainter * painter, const QRectF & rect)
+void PatienceView::drawBackground( QPainter * painter, const QRectF & rect )
 {
-    Q_UNUSED( rect );
-    QPixmap pix = Renderer::self()->renderElement( "background", sceneRect().size().toSize() );
-    painter->drawPixmap( sceneRect().topLeft(), pix );
+    QRectF source = rect.translated( -sceneRect().topLeft() );
+    if ( m_background.size() != size() )
+    {
+        qreal xScale = m_background.width() / width();
+        qreal yScale = m_background.height() / height();
+        source = QRectF( source.x() * xScale,
+                         source.y() * yScale,
+                         source.width() * xScale,
+                         source.height() * yScale );
+    }
+
+    painter->drawPixmap( rect, m_background, source );
+}
+
+
+void PatienceView::receivePixmap( const QPixmap & pixmap )
+{
+    m_background = pixmap;
+    resetCachedContent();
 }
 
 
