@@ -31,7 +31,7 @@
 #include <qpoint.h>
 #include <qstring.h>
 
-class KSvgRenderer;
+class QSvgRenderer;
 class QGraphicsSvgItem;
 
 namespace Ksirk
@@ -255,7 +255,7 @@ public:
     * Saves a XML representation of the country for game saving purpose
     * @param xmlStream The stream to write on
     */
-  void saveXml(std::ostream& xmlStream);
+  void saveXml(QTextStream& xmlStream);
 
   /** 
     * Transmit data about this country on the network, through the given 
@@ -378,7 +378,7 @@ public:
 
   QGraphicsSvgItem* m_highlighting;
 
-  KSvgRenderer* m_renderer;
+  QSvgRenderer* m_renderer;
 
   bool m_highlighting_locked;
 
